==> jupyterlab-code-snippets-2.1.0.tgz: package/lib/CodeSnippetEditorTags.js <==
// Copyright (c) 2020, jupytercalpoly
// Distributed under the terms of the BSD-3 Clause License.
import { checkIcon, addIcon } from '@jupyterlab/ui-components';
import React from 'react';
/**
 * CSS STYLING
 */
const CODE_SNIPPET_EDITOR_TAG = 'jp-codeSnippet-editor-tag';
const CODE_SNIPPET_EDITOR_TAG_PLUS_ICON = 'jp-codeSnippet-editor-tag-plusIcon';
const CODE_SNIPPET_EDITOR_TAG_LIST = 'jp-codeSnippet-editor-tagList';
export class CodeSnippetEditorTags extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            selectedTags: [],
            tags: [],
            plusIconShouldHide: false,
            addingNewTag: false,
        };
        this.renderTags = this.renderTags.bind(this);
        this.handleClick = this.handleClick.bind(this);
    }
    componentDidMount() {
        this.setState({
            selectedTags: this.props.selectedTags ? this.props.selectedTags : [],
            tags: this.props.snippetTags ? this.props.snippetTags : [],
            plusIconShouldHide: false,
            addingNewTag: false,
        });
    }
    componentDidUpdate(prevProps) {
        if (prevProps !== this.props) {
            this.setState({
                selectedTags: this.props.selectedTags ? this.props.selectedTags : [],
                tags: this.props.snippetTags ? this.props.snippetTags : [],
            });
        }
    }
    handleClick(event) {
        const target = event.target;
        const clickedTag = target.innerText;
        const parent = target.parentElement;
        this.setState((state) => ({
            selectedTags: this.handleClickHelper(parent, state.selectedTags ? state.selectedTags : [], clickedTag),
        }), this.handleOnChange);
    }
    handleOnChange() {
        this.props.handleChange(this.state.selectedTags, this.state.tags);
    }
    handleClickHelper(parent, tags, clickedTag) {
        const currentTags = tags.slice();
        if (parent.classList.contains('unapplied-tag')) {
            parent.classList.replace('unapplied-tag', 'applied-tag');
            currentTags.splice(-1, 0, clickedTag);
        }
        else if (parent.classList.contains('applied-tag')) {
            parent.classList.replace('applied-tag', 'unapplied-tag');
            const idx = currentTags.indexOf(clickedTag);
            currentTags.splice(idx, 1);
        }
        return currentTags;
    }
    addTagOnClick(event) {
        this.setState({ plusIconShouldHide: true, addingNewTag: true });
        const inputElement = event.target;
        if (inputElement.value === 'Add Tag') {
            inputElement.value = '';
            inputElement.style.width = '62px';
            inputElement.style.minWidth = '62px';
        }
    }
    addTagOnKeyDown(event) {
        const inputElement = event.target;
        if (inputElement.value !== '' && event.key === 'Enter') {
            if (this.state.tags.includes(inputElement.value)) {
                alert('Duplicate Tag Name!');
                return;
            }
            if (this.props.langTags.includes(inputElement.value)) {
                alert('This tag already exists in language tags!\nIf you want to create this tag, lowercase the first letter.');
                return;
            }
            const newTag = inputElement.value;
            // update state all tag and selected tag
            this.setState((state) => ({
                selectedTags: [...state.selectedTags, newTag],
                tags: [...state.tags, newTag],
                plusIconShouldHide: false,
                addingNewTag: false,
            }), this.handleOnChange);
        }
    }
    addTagOnBlur(event) {
        const inputElement = event.target;
        inputElement.value = 'Add Tag';
        inputElement.style.width = '50px';
        inputElement.style.minWidth = '50px';
        inputElement.blur();
        this.setState({ plusIconShouldHide: false, addingNewTag: false });
    }
    renderTags() {
        const hasTags = this.state.tags;
        const inputBox = this.state.addingNewTag === true ? (React.createElement("ul", { className: `${CODE_SNIPPET_EDITOR_TAG} tag unapplied-tag`, key: 'editor-new-tag' },
            React.createElement("input", { onClick: (event) => this.addTagOnClick(event), onKeyDown: (event) => this.addTagOnKeyDown(event), onBlur: (event) => this.addTagOnBlur(event), autoFocus: true }))) : (React.createElement("ul", { className: `${CODE_SNIPPET_EDITOR_TAG} tag unapplied-tag` },
            React.createElement("button", { onClick: () => this.setState({ addingNewTag: true }) }, "Add Tag"),
            React.createElement(addIcon.react, { tag: "span", className: CODE_SNIPPET_EDITOR_TAG_PLUS_ICON, elementPosition: "center", height: "16px", width: "16px", marginLeft: "2px" })));
        return (React.createElement("li", { className: CODE_SNIPPET_EDITOR_TAG_LIST },
            hasTags
                ? this.state.tags.map((tag, index) => (() => {
                    if (!this.state.selectedTags) {
                        return (React.createElement("ul", { className: `${CODE_SNIPPET_EDITOR_TAG} tag unapplied-tag`, id: 'editor' + '-' + tag + '-' + index, key: 'editor' + '-' + tag + '-' + index },
                            React.createElement("button", { onClick: this.handleClick }, tag)));
                    }
                    if (this.state.selectedTags.includes(tag)) {
                        return (React.createElement("ul", { className: `${CODE_SNIPPET_EDITOR_TAG} tag applied-tag`, id: 'editor' + '-' + tag + '-' + index, key: 'editor' + '-' + tag + '-' + index },
                            React.createElement("button", { onClick: this.handleClick }, tag),
                            React.createElement(checkIcon.react, { tag: "span", elementPosition: "center", height: "18px", width: "18px", marginLeft: "5px", marginRight: "-3px" })));
                    }
                    else {
                        return (React.createElement("ul", { className: `${CODE_SNIPPET_EDITOR_TAG} tag unapplied-tag`, id: 'editor' + '-' + tag + '-' + index, key: 'editor' + '-' + tag + '-' + index },
                            React.createElement("button", { onClick: this.handleClick }, tag)));
                    }
                })())
                : null,
            inputBox));
    }
    render() {
        return React.createElement("div", null, this.renderTags());
    }
}

==> jupyterlab-code-snippets-2.2.0.tgz: package/lib/CodeSnippetEditorTags.js <==
// Copyright (c) 2020, jupytercalpoly
// Distributed under the terms of the BSD-3 Clause License.
import { checkIcon, addIcon } from '@jupyterlab/ui-components';
import React from 'react';
/**
 * CSS STYLING
 */
const CODE_SNIPPET_EDITOR_TAG = 'jp-codeSnippet-editor-tag';
const CODE_SNIPPET_EDITOR_TAG_PLUS_ICON = 'jp-codeSnippet-editor-tag-plusIcon';
const CODE_SNIPPET_EDITOR_TAG_LIST = 'jp-codeSnippet-editor-tagList';
export class CodeSnippetEditorTags extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            allSnippetTags: [],
            plusIconClicked: false,
        };
        this.renderTags = this.renderTags.bind(this);
        this.handleClick = this.handleClick.bind(this);
    }
    componentDidMount() {
        this.setState({
            allSnippetTags: this.props.allSnippetTags,
            plusIconClicked: false,
        });
    }
    componentDidUpdate(prevProps) {
        if (prevProps !== this.props) {
            this.setState({
                allSnippetTags: this.props.allSnippetTags,
            });
        }
    }
    handleClick(event) {
        const target = event.target;
        const clickedTag = target.innerText;
        this.handleClickHelper(clickedTag);
    }
    handleOnChange() {
        this.props.handleChange(this.state.allSnippetTags);
    }
    handleClickHelper(
    // parent: HTMLElement,
    clickedTag) {
        this.setState((state) => ({
            allSnippetTags: state.allSnippetTags.map((tag) => tag.name === clickedTag ? Object.assign(Object.assign({}, tag), { clicked: !tag.clicked }) : tag),
        }), this.handleOnChange);
    }
    addTagOnClick(event) {
        this.setState({ plusIconClicked: true });
        const inputElement = event.target;
        if (inputElement.value === 'Add Tag') {
            inputElement.value = '';
            inputElement.style.width = '62px';
            inputElement.style.minWidth = '62px';
        }
    }
    addTagOnKeyDown(event) {
        const inputElement = event.target;
        if (inputElement.value !== '' && event.key === 'Enter') {
            if (this.state.allSnippetTags.find((tag) => tag.name === inputElement.value)) {
                alert('Duplicate Tag Name!');
                return;
            }
            if (this.props.langTags.includes(inputElement.value)) {
                alert('This tag already exists in language tags!\nIf you want to create this tag, lowercase the first letter.');
                return;
            }
            const newTag = { name: inputElement.value, clicked: true };
            this.setState((state) => ({
                allSnippetTags: [...state.allSnippetTags, newTag],
                plusIconClicked: false,
            }), this.handleOnChange);
        }
    }
    addTagOnBlur(event) {
        const inputElement = event.target;
        inputElement.value = 'Add Tag';
        inputElement.style.width = '50px';
        inputElement.style.minWidth = '50px';
        inputElement.blur();
        this.setState({ plusIconClicked: false });
    }
    renderTags() {
        const hasTags = this.state.allSnippetTags;
        const inputBox = this.state.plusIconClicked === true ? (React.createElement("ul", { className: `${CODE_SNIPPET_EDITOR_TAG} tag unapplied-tag`, key: 'editor-new-tag' },
            React.createElement("input", { onClick: (event) => this.addTagOnClick(event), onKeyDown: (event) => this.addTagOnKeyDown(event), onBlur: (event) => this.addTagOnBlur(event), autoFocus: true }))) : (React.createElement("ul", { className: `${CODE_SNIPPET_EDITOR_TAG} tag unapplied-tag` },
            React.createElement("button", { onClick: () => this.setState({ plusIconClicked: true }) }, "Add Tag"),
            React.createElement(addIcon.react, { tag: "span", className: CODE_SNIPPET_EDITOR_TAG_PLUS_ICON, elementPosition: "center", height: "16px", width: "16px", marginLeft: "2px" })));
        return (React.createElement("li", { className: CODE_SNIPPET_EDITOR_TAG_LIST },
            hasTags
                ? this.state.allSnippetTags.map((tag, index) => (() => {
                    if (!tag.clicked) {
                        return (React.createElement("ul", { className: `${CODE_SNIPPET_EDITOR_TAG} tag unapplied-tag`, id: 'editor' + '-' + tag.name + '-' + index, key: 'editor' + '-' + tag.name + '-' + index },
                            React.createElement("button", { onClick: this.handleClick }, tag.name)));
                    }
                    else {
                        return (React.createElement("ul", { className: `${CODE_SNIPPET_EDITOR_TAG} tag applied-tag`, id: 'editor' + '-' + tag.name + '-' + index, key: 'editor' + '-' + tag.name + '-' + index },
                            React.createElement("button", { onClick: this.handleClick }, tag.name),
                            React.createElement(checkIcon.react, { tag: "span", elementPosition: "center", height: "18px", width: "18px", marginLeft: "5px", marginRight: "-3px" })));
                    }
                })())
                : null,
            inputBox));
    }
    render() {
        return React.createElement("div", null, this.renderTags());
    }
}
